@@ -5,13 +5,9 @@ from inspect import Parameter
 import fastapi as _fastapi
 
 from context_handler import _datastructures
-from context_handler.generic import (
-    AsyncProviderT,
-    ClientT,
-    ProviderT,
-    _GenericAsyncContextFactory,
-    _GenericContextFactory,
-)
+from context_handler.generic import (AsyncProviderT, ClientT, ProviderT,
+                                     _GenericAsyncContextFactory,
+                                     _GenericContextFactory)
 from context_handler.getters import generate_state_name
 
 
@@ -26,19 +22,18 @@ def setup_context_cleaner_middleware(app: _fastapi.FastAPI):
         ],
     ):
         response = await call_next(request)
-        app_state_dict = object.__getattribute__(request.app.state, "_state")
-        request_state_dict = object.__getattribute__(request.state, "_state")
+        app_state_dict = object.__getattribute__(request.app.state, '_state')
+        request_state_dict = object.__getattribute__(request.state, '_state')
         provider_list = _get_provider_list(app_state_dict)
         contexts_from_provider = _get_contexts_from_providers(
             provider_list, request_state_dict
         )
-        contexts_by_type = _get_contexts_by_type(request_state_dict)
         await _close_active_contexts(
-            frozenset(contexts_from_provider + contexts_by_type)
+            contexts_from_provider
         )
         return response
 
-    app.middleware("http")(_context_cleaner_middleware)
+    app.middleware('http')(_context_cleaner_middleware)
 
 
 def _get_provider_list(
@@ -72,7 +67,7 @@ def _get_contexts_from_providers(
             ) is not None:
                 yield context
 
-    return list(_gen())
+    return frozenset(_gen())
 
 
 def _get_contexts_by_type(request_state_dict: typing.Dict[str, typing.Any]):
@@ -110,7 +105,7 @@ async def _close_active_contexts(
 
 def _get_param():
     return Parameter(
-        "has_state", Parameter.KEYWORD_ONLY, annotation=_fastapi.Request
+        'has_state', Parameter.KEYWORD_ONLY, annotation=_fastapi.Request
     )
 
 
